@@ -6,4 +6,8 @@ from .params import pgregistered as _
 from .processing import *
 from .params import *
 from .misc import *
-from . import fns, widgets
\ No newline at end of file
+from . import fns, widgets
+
+from .constants import PrjEnums
+import logging as _logging
+_logging.addLevelName(PrjEnums.LOG_LVL_ATTN, 'ATTN')
