@@ -19,7 +19,7 @@ import logging
 import docstring_parser as dp
 import pandas as pd
 import pyqtgraph as pg
-from pyqtgraph.Qt import QtWidgets, QtCore, QtGui
+from pyqtgraph.Qt import QtWidgets, QtCore, QtGui, QT_LIB
 from pyqtgraph.parametertree import Parameter, ParameterTree
 from tqdm import tqdm
 import cv2 as cv
@@ -53,6 +53,10 @@ def docParser(docstring: str, streamFormat='ini'):
   from ._funcparse import docParser as _dp
   return _dp(docstring, streamFormat)
 
+def funcToParamDict(func, title=None, **overrides):
+  from ._funcparse import funcToParamDict as _fpd
+  return _fpd(func, title, **overrides)
+
 def mproc_apply(func, iterLst, descr='', iterArgPos=0,
                 extraArgs=(), showProgress=True, applyAsync=True,
                 total=None, pool=None,
@@ -76,7 +80,7 @@ def mproc_apply(func, iterLst, descr='', iterArgPos=0,
   pre_results = []
   errs = {}
   def errCallback(fnArgs, ex):
-    errs[fnArgs[iterArgPos]] = str(ex)
+    errs[str(fnArgs[iterArgPos])] = str(ex)
 
   if debug:
     def applyFunc(func_, args):
@@ -311,12 +315,16 @@ def pascalCaseToTitle(name: str, addSpaces=True) -> str:
   """
   if not name:
     return name
-  if name.startswith('FR'):
-    name = name[2:]
-  replace = r'\1 \2' if addSpaces else r'\1\2'
-  name = re.sub(r'(\w)([A-Z])', replace, name)
+  replace = r' \1 '
+  # changeROIImage -> change ROI Image
+  # HTTPServer -> HTTP Server
+  # exportData -> export Data
+  name = re.sub(r'([A-Z]?[a-z0-9]+)', r' \1 ', name)
   name = name.replace('_', ' ')
-  return name.title().strip()
+  # title() would turn HTTPS -> Https which we don't want
+  parts = [p[0].upper() + p[1:] for p in name.split()]
+  joiner = ' ' if addSpaces else ''
+  return joiner.join(parts)
 
 # Make a class for reference persistence
 _nameFmtType = t.Callable[[str], str]
@@ -492,6 +500,20 @@ def setParamsExpanded(tree: ParameterTree, expandedVal=True):
       item.child(ii).setExpanded(expandedVal)
   tree.resizeColumnToContents(0)
 
+def forceRichText(text: str):
+  """
+  Wraps text in <qt> tags to make Qt treat it as rich text. Since tooltips don't wrap nicely unless text is rich,
+  this ensures all encountered tooltips are correctly wrapped.
+
+  :param text: text, may already start with <qt> tags
+  """
+  if 'PySide' in QT_LIB:
+    richDetect = QtGui.Qt.mightBeRichText
+  else:
+    richDetect = QtCore.Qt.mightBeRichText
+  if richDetect(text):
+    return text
+  return f'<qt>{text}</qt>'
 
 def setParamTooltips(tree: ParameterTree, expandNameCol=False):
   iterator = QtWidgets.QTreeWidgetItemIterator(tree)
@@ -506,7 +528,7 @@ def setParamTooltips(tree: ParameterTree, expandNameCol=False):
         and 'tip' in item.param.opts
         and len(item.toolTip(0)) == 0
         and tree.itemWidget(item, 0) is None):
-      item.setToolTip(0, item.param.opts['tip'])
+      item.setToolTip(0, forceRichText(item.param.opts['tip']))
     iterator += 1
     item = iterator.value()
   if expandNameCol:
@@ -520,7 +542,9 @@ def resolveYamlDict(cfgFname: FilePath, cfgDict: dict=None):
     if cfg is None:
       # Empty file
       cfg = {}
-  return Path(cfgFname), cfg
+  if cfgFname is not None:
+    cfgFname = Path(cfgFname)
+  return cfgFname, cfg
 
 
 def getParamChild(param: Parameter, *childPath: t.Sequence[str], allowCreate=True, groupOpts:dict=None,
@@ -781,15 +805,17 @@ def convertImages(globstr:str='*.*', ext='png', replace=True, folder: FilePath=N
       + '\n'.join(errs)
     )
 
-def hierarchicalUpdate(curDict: dict, other: dict, replaceLists=False):
+def hierarchicalUpdate(curDict: dict, other: dict, replaceLists=False, uniqueListElements=False):
   """Dictionary update that allows nested keys to be updated without deleting the non-updated keys"""
   if other is None:
     return curDict
   for k, v in other.items():
     curVal = curDict.get(k)
     if isinstance(curVal, dict) and isinstance(v, dict):
-      hierarchicalUpdate(curVal, v, replaceLists)
+      hierarchicalUpdate(curVal, v, replaceLists, uniqueListElements)
     elif not replaceLists and isinstance(curVal, list) and isinstance(v, list):
+      if uniqueListElements:
+        v = [el for el in v if el not in curVal]
       curVal.extend(v)
     else:
       curDict[k] = v
@@ -827,4 +853,22 @@ def gracefulNext(generator: t.Generator):
   try:
     return next(generator)
   except StopIteration as ex:
-    return ex.value
\ No newline at end of file
+    return ex.value
+
+def readDataFrameFiles(folder: FilePath,
+                       readFunc: t.Callable,
+                       globExpr='*.*',
+                       concatKwargs: dict=None,
+                       **readKwargs):
+  """
+  Reads files in a folder and concatenates them into one output dataframe
+
+  :param folder: Folder to find files
+  :param readFunc: Read function to use, must take file and ``readArgs`` to produce a dataframe.
+  :param globExpr: Optionally filter for specific files in ``folder`` by altering the glob expression
+  :param concatArgs: Dict of keywords passed to ``pd.concat``
+  :param readArgs: Passed to readFunc for each encountered file
+  """
+  files = Path(folder).glob(globExpr)
+  dfs = [readFunc(file, **readKwargs) for file in files]
+  return pd.concat(dfs, **(concatKwargs or {}))
