@@ -3,4 +3,8 @@ from .parameditor import *
 from .shortcut import ShortcutsEditor
 from .pgregistered import ShortcutParameter
 from .procwrapper import NestedProcWrapper
-from .plugin import dockPluginFactory, ParamEditorPlugin
\ No newline at end of file
+from .plugin import dockPluginFactory, ParamEditorPlugin
+from .. import fns
+
+from .._funcparse import RunOpts
+RunOpts.defaultCfg['title'] = fns.nameFormatter
\ No newline at end of file
