@@ -800,7 +800,7 @@ class ParamEditorDockGrouping(QtWidgets.QDockWidget):
 class EditorPropsMixin:
   __groupingName__: str = None
 
-  opts = {}
+  __editorPropertyOpts = {}
   """Options passed to kwargs during __initEditorParams__"""
 
   REGISTERED_GROUPINGS = set()
@@ -825,27 +825,27 @@ class EditorPropsMixin:
     with ParamEditor.setBaseRegisterPath(*basePath):
       # Check if kwargs are desired
       try:
-        inspect.signature(obj.__initEditorParams__).bind(**cls.opts)
+        inspect.signature(obj.__initEditorParams__).bind(**cls.__editorPropertyOpts)
       except TypeError:
         # Call without these kwargs
         obj.__initEditorParams__()
       else:
-        obj.__initEditorParams__(**cls.opts)
+        obj.__initEditorParams__(**cls.__editorPropertyOpts)
     return obj
 
   @classmethod
   @contextmanager
-  def setOpts(cls, **opts):
+  def setEditorPropertyOpts(cls, **opts):
     """
     sets the optios accociated with calls to __initEditorParams__ for instances of this class
     created inside the context manager
     """
-    oldOpts = cls.opts.copy()
-    cls.opts.update(opts)
+    oldOpts = cls.__editorPropertyOpts.copy()
+    cls.__editorPropertyOpts.update(opts)
     yield
     cls.opts = oldOpts
 
   def __initEditorParams__(self, **kwargs):
     pass
 
-SPAWNED_EDITORS: t.List[ParamEditor] = []
\ No newline at end of file
+SPAWNED_EDITORS: t.List[ParamEditor] = []
