@@ -573,13 +573,13 @@ class NoneParameter(parameterTypes.SimpleParameter):
     super().__init__(**opts)
     self.setWritable(False)
 
-parameterTypes.registerParameterType('nonetype', NoneParameter)
-parameterTypes.registerParameterType('NoneType', NoneParameter)
-parameterTypes.registerParameterType('keyseq', KeySequenceParameter)
-parameterTypes.registerParameterType('procgroup', ProcGroupParameter)
-parameterTypes.registerParameterType('shortcutkeyseq', ShortcutKeySeqParameter)
-parameterTypes.registerParameterType('shortcut', ShortcutParameter)
-parameterTypes.registerParameterType('popuplineeditor', PopupLineEditorParameter)
-parameterTypes.registerParameterType('filepicker', FilePickerParameter)
-parameterTypes.registerParameterType('slider', SliderParameter)
-parameterTypes.registerParameterType('checklist', ChecklistParameter)
+parameterTypes.registerParameterType('nonetype',        NoneParameter,            override=True)
+parameterTypes.registerParameterType('NoneType',        NoneParameter,            override=True)
+parameterTypes.registerParameterType('keyseq',          KeySequenceParameter,     override=True)
+parameterTypes.registerParameterType('procgroup',       ProcGroupParameter,       override=True)
+parameterTypes.registerParameterType('shortcutkeyseq',  ShortcutKeySeqParameter,  override=True)
+parameterTypes.registerParameterType('shortcut',        ShortcutParameter,        override=True)
+parameterTypes.registerParameterType('popuplineeditor', PopupLineEditorParameter, override=True)
+parameterTypes.registerParameterType('filepicker',      FilePickerParameter,      override=True)
+parameterTypes.registerParameterType('slider',          SliderParameter,          override=True)
+parameterTypes.registerParameterType('checklist',       ChecklistParameter,       override=True)
