@@ -642,15 +642,17 @@ class NestedProcess(ProcessStage):
         out.extend(stage._nonDisabledStages_flattened())
     return out
 
-  def stageSummary_gui(self):
+  def stageSummary_gui(self, show=True):
     if self.result is None:
       raise RuntimeError('Analytics can only be shown after the algorithm was run.')
     outGrid = self._stageSummaryWidget()
-    outGrid.showMaximized()
-    def fixedShow():
-      for item in outGrid.ci.items:
-        item.getViewBox().autoRange()
-    QtCore.QTimer.singleShot(0, fixedShow)
+    if show:
+      outGrid.showMaximized()
+      def fixedShow():
+        for item in outGrid.ci.items:
+          item.getViewBox().autoRange()
+      QtCore.QTimer.singleShot(0, fixedShow)
+    return outGrid
 
   def getAllStageInfos(self, ignoreDuplicates=True, ignoreDisabled=True):
     allInfos: _infoType = []
@@ -733,4 +735,4 @@ class ArgMapper(AtomicProcess):
       out = ProcessIO()
     for kk, vv in self.defaultInput.items():
       out[kk] = kwargs[vv]
-    return out
\ No newline at end of file
+    return out
