@@ -25,7 +25,7 @@ from pyqtgraph.graphicsItems.ViewBox.ViewBoxMenu import ViewBoxMenu
 from pyqtgraph.parametertree import Parameter
 
 from utilitys.fns import nameFormatter, pascalCaseToTitle, params_flattened, \
-  dynamicDocstring, getParamChild, hookupParamWidget, timedExec
+  dynamicDocstring, getParamChild, hookupParamWidget, timedExec, forceRichText
 from utilitys.misc import CompositionMixin
 from utilitys.typeoverloads import FilePath
 from . import params
@@ -104,7 +104,7 @@ def safeSpawnDevConsole(win: QtWidgets.QMainWindow, **locals):
   except Exception:
     # Ipy kernel can have issues for many different reasons. Always be ready to fall back to traditional console
     console = pg.console.ConsoleWidget(parent=win, namespace=locals, text=text)
-  console.setWindowFlags(QtCore.Qt.WindowFlag.Window)
+  console.setWindowFlag(QtCore.Qt.WindowType.Window)
   console.show()
 
 class ScrollableMessageDialog(QtWidgets.QDialog):
@@ -404,7 +404,7 @@ class ButtonCollection(QtWidgets.QGroupBox):
       newBtn.setText('')
       newBtn.setIcon(QtGui.QIcon(str(btnOpts.opts['icon'])))
       tooltipText = btnOpts.addHelpText(btnOpts.name)
-    newBtn.setToolTip(tooltipText)
+    newBtn.setToolTip(forceRichText(tooltipText))
     reg = params.pgregistered.ShortcutParameter.REGISTRY
     if reg is not None:
       reg.registerButton(btnOpts, newBtn, **kwargs)
@@ -729,8 +729,8 @@ class CompositorItemSample(ItemSample):
       p.setRenderHint(p.Antialiasing)
     symbol = opts.get('symbol', None)
     p.translate(0, 14)
-    drawSymbol(p, symbol, opts['size'], pg.fn.mkPen(opts['pen']),
-               pg.fn.mkBrush(opts['brush']))
+    drawSymbol(p, symbol, opts['size'], pg.mkPen(opts['pen']),
+               pg.mkBrush(opts['brush']))
 
 class CompositorLegend(pg.LegendItem):
 
@@ -1366,4 +1366,4 @@ class FadeNotifyHandler(TimedMessageHandler):
     widget.setGraphicsEffect(effect)
     anim = timedExec(changeOpacity, interval_ms=0)
     self.msgRefs[widget] = anim
-    return anim
\ No newline at end of file
+    return anim
